## Version 2.2 

## Removed

- Removes related identifiers, in favour of "sources", as per DataPackage v2.

## Version 2.1.2

### Added

- Dataset page with summary of existing datasets, generated by querying the Zenodo API for the Paralex community.

## Version 2.1.1

### Changed

- Fixed cell validator

### Removed

- Fake iso key in default package

## Version 2.1.0

### Added

- Examples section in docs
- **breaking** Listing text and bib files in the metadata
- Doc and validation about bib sources
- **breaking** Changed from Zenodo style related identifiers to Frictionless `sources`

### Changed

- Fixed tag validation


## Version 2.0.0

### Added

- Store package version

### Changed

- Handling basepath as in `frictionless`
- **breaking** Adding language iso 639 codes to metadata (`languages_iso639`)
- Supporting multipaths / multi parts csv files
- Homogeneized columns for cells and feature-values
